summaryrefslogtreecommitdiff
path: root/framework
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2018-01-15 09:11:52 +0100
committerMichael Stahl <mstahl@redhat.com>2018-01-15 13:53:21 +0100
commita6b69a9384801f77f4cc30a366a45561c28eab3e (patch)
tree983661741b4081501f37365afa84a08b761000e7 /framework
parent3da86d8987db6223b0acc5d8a1b56f7e0c54bbef (diff)
Fix typo
Change-Id: I51c97356c9c2939f2d94d6388c829a179ca00daa Reviewed-on: https://gerrit.libreoffice.org/47853 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Michael Stahl <mstahl@redhat.com>
Diffstat (limited to 'framework')
-rw-r--r--framework/source/services/autorecovery.cxx16
-rw-r--r--framework/source/services/frame.cxx10
2 files changed, 13 insertions, 13 deletions
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 8ba3e8487bad..861cfcffe1d7 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -202,7 +202,7 @@ public:
/* FINAL STATES */
- /// the Auto/Emergency saved document is not useable any longer
+ /// the Auto/Emergency saved document is not usable any longer
E_DAMAGED = 64,
/// the Auto/Emergency saved document is not really up-to-date (some changes can be missing)
E_INCOMPLETE = 128,
@@ -1580,7 +1580,7 @@ void SAL_CALL AutoRecovery::documentEventOccured(const css::document::DocumentEv
}
// If saving of a document failed by an error ... we have to save this document
// by ourself next time AutoSave or EmergencySave is triggered.
// But we can reset the state "used for other save requests". Otherwhise
// these documents will never be saved!
else if (
(aEvent.EventName == EVENT_ON_SAVEFAILED) ||
@@ -2398,7 +2398,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
if (bNoAutoSave)
return;
// Check if doc is well known on the desktop. Otherwhise ignore it!
// Other frames mostly are used from external programs - e.g. the bean ...
css::uno::Reference< css::frame::XController > xController = xDocument->getCurrentController();
if (!xController.is())
@@ -2510,7 +2510,7 @@ void AutoRecovery::implts_deregisterDocument(const css::uno::Reference< css::fra
// Sometimes we close documents by ourself.
// And these documents can't be deregistered.
// Otherwhise we lose our configuration data... but need it !
// see SessionSave !
if (aInfo.IgnoreClosing)
return;
@@ -2766,7 +2766,7 @@ void AutoRecovery::implts_prepareSessionShutdown()
// Prevent us from deregistration of these documents.
// Because we close these documents by ourself (see XClosable below) ...
// it's fact, that we reach our deregistration method. There we
// must not(!) update our configuration ... Otherwhise all
// session data are lost !!!
rInfo.IgnoreClosing = true;
@@ -3030,7 +3030,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
lNewArgs[utl::MediaDescriptor::PROP_ENCRYPTIONDATA()] <<= aEncryptionData;
// Further it must be saved using the default file format of that application.
// Otherwhise we will some data lost.
if (!rInfo.DefaultFilter.isEmpty())
lNewArgs[utl::MediaDescriptor::PROP_FILTERNAME()] <<= rInfo.DefaultFilter;
@@ -3325,7 +3325,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
/* Normally we listen as XModifyListener on a document to know if a document was changed
since our last AutoSave. And we deregister us in case we know this state.
But directly after one document as recovered ... we must start listening.
- Otherwhise the first "modify" doesn't reach us. Because we ourself called setModified()
+ Otherwise the first "modify" doesn't reach us. Because we ourself called setModified()
on the document via API. And currently we don't listen for any events (not at theGlobalEventBroadcaster
nor at any document!).
*/
@@ -4057,7 +4057,7 @@ bool AutoRecovery::impl_enoughDiscSpace(sal_Int32 nRequiredSpace)
#else // SIMULATE_FULL_DISC
// In case an error occurs and we are not able to retrieve the needed information
// it's better to "disable" the feature ShowErrorOnFullDisc !
// Otherwhise we start a confusing process of error handling ...
sal_uInt64 nFreeSpace = SAL_MAX_UINT64;
@@ -1580,7 +1580,7 @@ void SAL_CALL AutoRecovery::documentEventOccured(const css::document::DocumentEv
// If saving of a document failed by an error ... we have to save this document
// by ourself next time AutoSave or EmergencySave is triggered.
- // But we can reset the state "used for other save requests". Otherwhise
+ // But we can reset the state "used for other save requests". Otherwise
// these documents will never be saved!
else if (
@@ -2398,7 +2398,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
if (bNoAutoSave)
return;
- // Check if doc is well known on the desktop. Otherwhise ignore it!
+ // Check if doc is well known on the desktop. Otherwise ignore it!
// Other frames mostly are used from external programs - e.g. the bean ...
css::uno::Reference< css::frame::XController > xController = xDocument->getCurrentController();
@@ -2510,7 +2510,7 @@ void AutoRecovery::implts_deregisterDocument(const css::uno::Reference< css::fra
// Sometimes we close documents by ourself.
// And these documents can't be deregistered.
- // Otherwhise we lose our configuration data... but need it !
+ // Otherwise we lose our configuration data... but need it !
// see SessionSave !
if (aInfo.IgnoreClosing)
@@ -2766,7 +2766,7 @@ void AutoRecovery::implts_prepareSessionShutdown()
// Because we close these documents by ourself (see XClosable below) ...
// it's fact, that we reach our deregistration method. There we
- // must not(!) update our configuration ... Otherwhise all
+ // must not(!) update our configuration ... Otherwise all
// session data are lost !!!
rInfo.IgnoreClosing = true;
@@ -3030,7 +3030,7 @@ void AutoRecovery::implts_saveOneDoc(const OUString&
lNewArgs[utl::MediaDescriptor::PROP_ENCRYPTIONDATA()] <<= aEncryptionData;
// Further it must be saved using the default file format of that application.
- // Otherwhise we will some data lost.
+ // Otherwise we will some data lost.
if (!rInfo.DefaultFilter.isEmpty())
lNewArgs[utl::MediaDescriptor::PROP_FILTERNAME()] <<= rInfo.DefaultFilter;
@@ -4057,7 +4057,7 @@ bool AutoRecovery::impl_enoughDiscSpace(sal_Int32 nRequiredSpace)
// In case an error occurs and we are not able to retrieve the needed information
// it's better to "disable" the feature ShowErrorOnFullDisc !
- // Otherwhise we start a confusing process of error handling ...
+ // Otherwise we start a confusing process of error handling ...
sal_uInt64 nFreeSpace = SAL_MAX_UINT64;
diff --git a/framework/source/services/frame.cxx b/framework/source/services/frame.cxx
index 2f2011d60364..adc174a8ad3a 100644
--- a/framework/source/services/frame.cxx
+++ b/framework/source/services/frame.cxx
@@ -985,7 +985,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::findFrame( const OUStr
// I.III) "_top"
// If we are not the top frame in this hierarchy, we must forward request to our parent.
// Otherwhise we must return ourself.
else if ( sTargetFrameName==SPECIALTARGET_TOP )
{
@@ -1404,7 +1404,7 @@ void SAL_CALL Frame::contextChanged()
May <NULL/> for releasing.
@param xController
reference to new component controller
- (may <NULL/> for relasing or setting of a simple component)
+ (may <NULL/> for releasing or setting of a simple component)
@return <TRUE/> if operation was successful, <FALSE/> otherwise.
@@ -1626,7 +1626,7 @@ void SAL_CALL Frame::removeFrameActionListener( const css::uno::Reference< css::
@param bDeliverOwnership
If parameter is set to <FALSE/> the original caller will be the owner after thrown
- veto exception and must try to close this frame at later time again. Otherwhise the
+ veto exception and must try to close this frame at later time again. Otherwise the
source of throwed exception is the right one. May it will be the frame himself.
@throws CloseVetoException
@@ -2105,7 +2105,7 @@ void SAL_CALL Frame::disposing()
// Don't show any dialogs, errors or something else any more!
// If somewhere called dispose() whitout close() before - normally no dialogs
// should exist. Otherwhise it's the problem of the outside caller.
// Note:
// (a) Do it after stopWindowListening(). May that force some active/deactive
// notifications which we don't need here really.
@@ -2529,7 +2529,7 @@ void SAL_CALL Frame::windowClosing( const css::lang::EventObject& )
/*ATTENTION!
Don't try to suspend the controller here! Because it's done inside used dispatch().
- Otherwhise the dialog "would you save your changes?" will be shown more than once ...
+ Otherwise the dialog "would you save your changes?" will be shown more than once ...
*/
css::util::URL aURL;
@@ -985,7 +985,7 @@ css::uno::Reference< css::frame::XFrame > SAL_CALL Frame::findFrame( const OUStr
// I.III) "_top"
// If we are not the top frame in this hierarchy, we must forward request to our parent.
- // Otherwhise we must return ourself.
+ // Otherwise we must return ourself.
else if ( sTargetFrameName==SPECIALTARGET_TOP )
{
@@ -2105,7 +2105,7 @@ void SAL_CALL Frame::disposing()
// Don't show any dialogs, errors or something else any more!
// If somewhere called dispose() whitout close() before - normally no dialogs
- // should exist. Otherwhise it's the problem of the outside caller.
+ // should exist. Otherwise it's the problem of the outside caller.
// Note:
// (a) Do it after stopWindowListening(). May that force some active/deactive